@@ -1,6 +1,6 @@
 import numpy
 import datetime
-from nfsmi_hj3415.db import Corps, Settings
+from stock_core.load_db import Corps, Settings
 import logging
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
