@@ -419,7 +419,7 @@ class Score:
                 return NEG_MAX, NEG_MAX
             std = numpy.std(d_values)
             logger.info(f'표준편차 : {std}')
-            p += NEG_MAX if round(std) > -NEG_MAX else -round(std)
+            p += NEG_MAX if round(float(std)) > -NEG_MAX else -round(float(std))
             logger.info(f'point 순운전자본회전율 : {p}')
             return p, NEG_MAX
 
@@ -446,7 +446,7 @@ class Score:
                 return NEG_MAX, NEG_MAX
             std = numpy.std(d_values)
             logger.info(f'표준편차 : {std}')
-            p += NEG_MAX if round(std) > -NEG_MAX else -round(std)
+            p += NEG_MAX if round(float(std)) > -NEG_MAX else -round(float(std))
             logger.info(f'point 재고자산회전율 : {p}')
             return p, NEG_MAX
 
@@ -495,14 +495,14 @@ class Score:
             d_values = list(매출액증가율.values())
             logger.info(f'd_values : {d_values}')
             if len(d_values) == 0:
-                return p
-            mean = round(numpy.mean(d_values))
-            #std = round(numpy.std(d_values))
-            logger.info(f'평균 : {mean}')
-            #logger.info(f'표준편차 : {std}')
-            p += 0 if mean < 0 else round(mean / 10)
+                return p, float('nan')
+            my_mean = round(float(numpy.mean(d_values)))
+            # std = round(numpy.std(d_values))
+            logger.info(f'평균 : {my_mean}')
+            # logger.info(f'표준편차 : {std}')
+            p += 0 if my_mean < 0 else round(my_mean / 10)
             logger.info(f'point 매출액증가율 : {p}')
-            return p, mean
+            return p, my_mean
 
         def 영업이익률평가() -> int:
             # 영업이익률은 기업의 경쟁력척도로 경쟁사에 비해 높으면 경제적해자를 갖춘셈
@@ -552,166 +552,184 @@ class Score:
         return neg_p, TOTAL_NEG_MAX, pos_p, mean
 
 
-def report_one(code: str) -> str:
-    def deco_num(x: str) -> str:
-        return None if x is None or math.isnan(float(x)) else format(int(x), ",")
-
-    def c101_str(all_dict: dict) -> str:
-        c101d = all_dict['c101']
-        logger.info(c101d)
-        title = '=' * 35 + f"\t{c101d['코드']}\t\t{c101d['종목명']}\t\t{c101d['업종']}\t" + '=' * 35
-        import textwrap
-        intro = textwrap.fill(f"{c101d['intro']}", width=70)
-        price = (f"{c101d['date']}\t\t"
-                 f"주가: {deco_num(c101d['주가'])}원\t\t"
-                 f"52주최고: {deco_num(c101d['최고52주'])}원\t"
-                 f"52주최저: {deco_num(c101d['최저52주'])}원")
-        info = (f"PER: {c101d['PER']}\t\t"
-                f"PBR: {c101d['PBR']}\t\t\t"
-                f"배당수익률: {c101d['배당수익률']}%\t\t"
-                 f"시가총액: {deco_num(c101d['시가총액'])}억\n"
-                f"업종PER: {c101d['업종PER']}\t"
-                f"유통비율: {c101d['유통비율']}%\t\t"
-                f"거래대금: {utils.to_억(c101d['거래대금'])}원\t"
-                f"발행주식: {utils.to_만(c101d['발행주식'])}주")
-        return title + '\n' + intro + seperate_line + price + '\n' + info
-
-    def red_str(all_dict: dict, red_p: tuple) -> str:
-        red, 괴리율 = red_p
-        red_dict = all_dict['red']
-        logger.info(red_dict)
-        return (f"Red Price\tPoint({red})\n"
-                f"사업가치({deco_num(red_dict['사업가치'])}억) "
-                f"+ 재산가치({deco_num(red_dict['재산가치'])}억) "
-                f"- 부채({deco_num(red_dict['부채평가'])}억) "
-                f"/ 발행주식({utils.to_만(red_dict['발행주식수'])}주) "
-                f"= {deco_num(red_dict['red_price'])}원")
-
-    def mil_str(all_dict: dict, mil_p: tuple) -> str:
-        mil, MAX = mil_p
-        mil_dict = all_dict['mil']
-        logger.info(mil_dict)
-        return (f"Millenial\tPoint({mil}/{MAX})\n"
-                f"1. 주주수익률: {mil_dict['주주수익률']} %\n"
-                f"2. 이익지표: {mil_dict['이익지표']}\n"
-                f"3. 투자수익률: ROIC 4분기합: {mil_dict['투자수익률']['ROIC']}%, 최근 ROE: {mil_dict['투자수익률']['ROE']}%\n"
-                f"4. 가치지표\n"
-                f"\tFCF: {mil_dict['가치지표']['FCF']}\n"
-                f"\tPFCF : {mil_dict['가치지표']['PFCF']}\n"
-                f"\tPCR: {mil_dict['가치지표']['PCR']}")
-
-    def blue_str(all_dict: dict, blue_p: tuple) -> str:
-        neg_p, NEG_MAX, pos_p, mean = blue_p
-        blue_dict = all_dict['blue']
-        logger.info(blue_dict)
-        return (f"Blue\t - Point({neg_p}/{NEG_MAX})\t+ Point({pos_p})\n"
-                f"1. 유동비율: {blue_dict['유동비율']}(100이하 위험)\n"
-                f"2. 이자보상배율: {blue_dict['이자보상배율']}(1이하 위험 5이상 양호)\n"
-                f"3. 순운전자본회전율: {blue_dict['순운전자본회전율']}\n"
-                f"4. 재고자산회전율: {blue_dict['재고자산회전율']}\n"
-                f"5. 순부채비율: {blue_dict['순부채비율']}(30이상 not good)\n"
-                f"6. 매출액증가율: {blue_dict['매출액증가율']}\n"
-                f"\t평균매출액증가율: {mean}\n"
-                f"7. 영업이익률: {blue_dict['영업이익률']}")
-
-    def c108_str(all_dict: dict) -> str:
-        s = ''
-        for i, c108_dict in enumerate(all_dict['c108']):
-            logger.info(c108_dict)
-            opinion = c108_dict['내용'].replace('▶', '\n\t')
-            if i == 0:
-                pass
-            else:
-                s += '\n'
-            s += f"{c108_dict['날짜']}\thprice : {c108_dict['목표가']} 원\n<<{c108_dict['제목']}>>{opinion}"
-        return s
-
-    s = Score(code)
-    d = s.eval_dict
-
-    seperate_line = '\n' + ('-' * 100) + '\n'
-
-    return (c101_str(d) + seperate_line
-            + red_str(d, s.red()) + seperate_line
-            + mil_str(d, s.mil()) + seperate_line
-            + blue_str(d, s.blue()) + seperate_line
-            + c108_str(d) + seperate_line)
-
-
-def telegram_one(code: str) -> str:
-    def deco_num(x: str) -> str:
-        return None if x is None or math.isnan(float(x)) else format(int(x), ",")
-
-    def c101_str(all_dict: dict) -> str:
-        c101d = all_dict['c101']
-        logger.info(c101d)
-        title = '=' * 35 + f"\t{c101d['코드']}\t\t{c101d['종목명']}\t\t{c101d['업종']}\t" + '=' * 35
-
-        intro = f"{c101d['intro']}"
-        price = (f"<< {c101d['date']} >>\n"
-                 f"주가: {deco_num(c101d['주가'])}원\n"
-                 f"52주최고: {deco_num(c101d['최고52주'])}원\n"
-                 f"52주최저: {deco_num(c101d['최저52주'])}원")
-        info = (f"PER: {c101d['PER']}\n"
-                f"업종PER: {c101d['업종PER']}\n"
-                f"PBR: {c101d['PBR']}\n"
-                f"배당수익률: {c101d['배당수익률']}%\n"
-                f"유통비율: {c101d['유통비율']}%\n"
-                f"거래대금: {utils.to_억(c101d['거래대금'])}원\n"
-                f"발행주식: {utils.to_만(c101d['발행주식'])}주\n"
-                f"시가총액: {deco_num(c101d['시가총액'])}억")
-        return title + '\n' + intro + seperate_line + price + '\n' + info
-
-    def red_str(all_dict: dict, red_p: tuple) -> str:
-        red, 괴리율 = red_p
-        red_dict = all_dict['red']
-        logger.info(red_dict)
-        return (f"<< Red Price >> Point({red})\n"
-                f"{deco_num(red_dict['red_price'])}원\n"
-                f"괴리율({괴리율}%)")
-
-    def mil_str(all_dict: dict, mil_p: tuple) -> str:
-        mil, MAX = mil_p
-        mil_dict = all_dict['mil']
-        logger.info(mil_dict)
-        return (f"<< Millenial >> Point({mil}/{MAX})\n"
-                f"1. 주주수익률: {mil_dict['주주수익률']} %\n"
-                f"2. 이익지표: {mil_dict['이익지표']}\n"
-                f"3. 투자수익률\nROIC 4분기합: {mil_dict['투자수익률']['ROIC']}%\n최근 ROE: {mil_dict['투자수익률']['ROE']}%\n"
-                f"4. 가치지표\n"
-                f"FCF\n{mil_dict['가치지표']['FCF']}\n"
-                f"PFCF\n{mil_dict['가치지표']['PFCF']}\n"
-                f"PCR\n{mil_dict['가치지표']['PCR']}")
-
-    def blue_str(all_dict: dict, blue_p: tuple) -> str:
-        neg_p, NEG_MAX, pos_p, mean = blue_p
-        blue_dict = all_dict['blue']
-        logger.info(blue_dict)
-        return (f"<< Blue >>\n"
-                f"Neg_P: {neg_p}/{NEG_MAX}\n"
-                f"Pos_P: {pos_p}\n"
-                f"평균매출액증가율: {mean}%\n"
-                f"영업이익률\n{blue_dict['영업이익률']}")
-
-    def c108_str(all_dict: dict) -> str:
-        s = ''
-        for i, c108_dict in enumerate(all_dict['c108']):
-            logger.info(c108_dict)
-            opinion = c108_dict['내용'].replace('▶', '\n\t')
-            if i == 0:
-                pass
-            else:
-                s += '\n'
-            s += f"{c108_dict['날짜']}\thprice : {c108_dict['목표가']} 원\n<<{c108_dict['제목']}>>{opinion}"
-        return s
-
-    s = Score(code)
-    d = s.eval_dict
-
+class ReportOne:
+    """
+    Eval클래스와 Score클래스를 같이 계산하여 다양한 방식의 출력구조에 맞춰 형식을 반환한다.
+    즉 Eval과 Score를 외부에서 직적 사용할 필요없이 ReportOne클래스를 사용한다.
+    """
     seperate_line = '\n' + ('-' * 65) + '\n'
 
-    return (c101_str(d) + seperate_line
-            + red_str(d, s.red()) + seperate_line
-            + mil_str(d, s.mil()) + seperate_line
-            + blue_str(d, s.blue()) + seperate_line
-            + c108_str(d) + seperate_line)
+    def __init__(self, code: str):
+        self.code = code
+        s = Score(code)
+        self.eval_dict = s.eval_dict
+        self.red_scores = s.red()
+        self.mil_scores = s.mil()
+        self.blue_scores = s.blue()
+
+    @staticmethod
+    def deco_num(x: str) -> str:
+        # 숫자의 세자리마다 콤마를 붙여 읽기 쉽게 만들어 준다.
+        return None if x is None or math.isnan(float(x)) else format(int(x), ",")
+
+    def for_console(self) -> str:
+        def c101_str() -> str:
+            c101d = self.eval_dict['c101']
+            logger.info(c101d)
+            title = '=' * 35 + f"\t{c101d['코드']}\t\t{c101d['종목명']}\t\t{c101d['업종']}\t" + '=' * 35
+            import textwrap
+            intro = textwrap.fill(f"{c101d['intro']}", width=70)
+            price = (f"{c101d['date']}\t\t"
+                     f"주가: {self.deco_num(c101d['주가'])}원\t\t"
+                     f"52주최고: {self.deco_num(c101d['최고52주'])}원\t"
+                     f"52주최저: {self.deco_num(c101d['최저52주'])}원")
+            info = (f"PER: {c101d['PER']}\t\t"
+                    f"PBR: {c101d['PBR']}\t\t\t"
+                    f"배당수익률: {c101d['배당수익률']}%\t\t"
+                    f"시가총액: {self.deco_num(c101d['시가총액'])}억\n"
+                    f"업종PER: {c101d['업종PER']}\t"
+                    f"유통비율: {c101d['유통비율']}%\t\t"
+                    f"거래대금: {utils.to_억(c101d['거래대금'])}원\t"
+                    f"발행주식: {utils.to_만(c101d['발행주식'])}주")
+            return title + '\n' + intro + self.seperate_line + price + '\n' + info
+
+        def red_str() -> str:
+            red, 괴리율 = self.red_scores
+            red_dict = self.eval_dict['red']
+            logger.info(red_dict)
+            return (f"Red Price\tPoint({red})\n"
+                    f"사업가치({self.deco_num(red_dict['사업가치'])}억) "
+                    f"+ 재산가치({self.deco_num(red_dict['재산가치'])}억) "
+                    f"- 부채({self.deco_num(red_dict['부채평가'])}억) "
+                    f"/ 발행주식({utils.to_만(red_dict['발행주식수'])}주) "
+                    f"= {self.deco_num(red_dict['red_price'])}원")
+
+        def mil_str() -> str:
+            mil, MAX = self.mil_scores
+            mil_dict = self.eval_dict['mil']
+            logger.info(mil_dict)
+            return (f"Millenial\tPoint({mil}/{MAX})\n"
+                    f"1. 주주수익률: {mil_dict['주주수익률']} %\n"
+                    f"2. 이익지표: {mil_dict['이익지표']}\n"
+                    f"3. 투자수익률: ROIC 4분기합: {mil_dict['투자수익률']['ROIC']}%, 최근 ROE: {mil_dict['투자수익률']['ROE']}%\n"
+                    f"4. 가치지표\n"
+                    f"\tFCF: {mil_dict['가치지표']['FCF']}\n"
+                    f"\tPFCF : {mil_dict['가치지표']['PFCF']}\n"
+                    f"\tPCR: {mil_dict['가치지표']['PCR']}")
+
+        def blue_str() -> str:
+            neg_p, NEG_MAX, pos_p, mean = self.blue_scores
+            blue_dict = self.eval_dict['blue']
+            logger.info(blue_dict)
+            return (f"Blue\t - Point({neg_p}/{NEG_MAX})\t+ Point({pos_p})\n"
+                    f"1. 유동비율: {blue_dict['유동비율']}(100이하 위험)\n"
+                    f"2. 이자보상배율: {blue_dict['이자보상배율']}(1이하 위험 5이상 양호)\n"
+                    f"3. 순운전자본회전율: {blue_dict['순운전자본회전율']}\n"
+                    f"4. 재고자산회전율: {blue_dict['재고자산회전율']}\n"
+                    f"5. 순부채비율: {blue_dict['순부채비율']}(30이상 not good)\n"
+                    f"6. 매출액증가율: {blue_dict['매출액증가율']}\n"
+                    f"\t평균매출액증가율: {mean}\n"
+                    f"7. 영업이익률: {blue_dict['영업이익률']}")
+
+        def c108_str() -> str:
+            s = ''
+            for i, c108_dict in enumerate(self.eval_dict['c108']):
+                logger.info(c108_dict)
+                opinion = c108_dict['내용'].replace('▶', '\n\t')
+                if i == 0:
+                    pass
+                else:
+                    s += '\n'
+                s += f"{c108_dict['날짜']}\thprice : {c108_dict['목표가']} 원\n<<{c108_dict['제목']}>>{opinion}"
+            return s
+
+        return (c101_str() + self.seperate_line
+                + red_str() + self.seperate_line
+                + mil_str() + self.seperate_line
+                + blue_str() + self.seperate_line
+                + c108_str() + self.seperate_line)
+
+    def for_telegram(self) -> str:
+        def c101_str() -> str:
+            c101d = self.eval_dict['c101']
+            logger.info(c101d)
+            title = '=' * 35 + f"\t{c101d['코드']}\t\t{c101d['종목명']}\t\t{c101d['업종']}\t" + '=' * 35
+
+            intro = f"{c101d['intro']}"
+            price = (f"<< {c101d['date']} >>\n"
+                     f"주가: {self.deco_num(c101d['주가'])}원\n"
+                     f"52주최고: {self.deco_num(c101d['최고52주'])}원\n"
+                     f"52주최저: {self.deco_num(c101d['최저52주'])}원")
+            info = (f"PER: {c101d['PER']}\n"
+                    f"업종PER: {c101d['업종PER']}\n"
+                    f"PBR: {c101d['PBR']}\n"
+                    f"배당수익률: {c101d['배당수익률']}%\n"
+                    f"유통비율: {c101d['유통비율']}%\n"
+                    f"거래대금: {utils.to_억(c101d['거래대금'])}원\n"
+                    f"발행주식: {utils.to_만(c101d['발행주식'])}주\n"
+                    f"시가총액: {self.deco_num(c101d['시가총액'])}억")
+            return title + '\n' + intro + self.seperate_line + price + '\n' + info
+
+        def red_str() -> str:
+            red, 괴리율 = self.red_scores
+            red_dict = self.eval_dict['red']
+            logger.info(red_dict)
+            return (f"<< Red Price >> Point({red})\n"
+                    f"{self.deco_num(red_dict['red_price'])}원\n"
+                    f"괴리율({괴리율}%)")
+
+        def mil_str() -> str:
+            mil, MAX = self.mil_scores
+            mil_dict = self.eval_dict['mil']
+            logger.info(mil_dict)
+            return (f"<< Millenial >> Point({mil}/{MAX})\n"
+                    f"1. 주주수익률: {mil_dict['주주수익률']} %\n"
+                    f"2. 이익지표: {mil_dict['이익지표']}\n"
+                    f"3. 투자수익률\nROIC 4분기합: {mil_dict['투자수익률']['ROIC']}%\n최근 ROE: {mil_dict['투자수익률']['ROE']}%\n"
+                    f"4. 가치지표\n"
+                    f"FCF\n{mil_dict['가치지표']['FCF']}\n"
+                    f"PFCF\n{mil_dict['가치지표']['PFCF']}\n"
+                    f"PCR\n{mil_dict['가치지표']['PCR']}")
+
+        def blue_str() -> str:
+            neg_p, NEG_MAX, pos_p, mean = self.blue_scores
+            blue_dict = self.eval_dict['blue']
+            logger.info(blue_dict)
+            return (f"<< Blue >>\n"
+                    f"Neg_P: {neg_p}/{NEG_MAX}\n"
+                    f"Pos_P: {pos_p}\n"
+                    f"평균매출액증가율: {mean}%\n"
+                    f"영업이익률\n{blue_dict['영업이익률']}")
+
+        def c108_str() -> str:
+            s = ''
+            for i, c108_dict in enumerate(self.eval_dict['c108']):
+                logger.info(c108_dict)
+                opinion = c108_dict['내용'].replace('▶', '\n\t')
+                if i == 0:
+                    pass
+                else:
+                    s += '\n'
+                s += f"{c108_dict['날짜']}\thprice : {c108_dict['목표가']} 원\n<<{c108_dict['제목']}>>{opinion}"
+            return s
+
+        return (c101_str() + self.seperate_line
+                + red_str() + self.seperate_line
+                + mil_str() + self.seperate_line
+                + blue_str() + self.seperate_line
+                + c108_str() + self.seperate_line)
+
+    def for_django(self) -> dict:
+        """
+        장고의 view context는 딕셔너리 형식이기 때문에 딕셔너리 모음으로 반환한다.
+        """
+        return {
+            'c101': self.eval_dict['c101'],
+            'red': self.eval_dict['red'],
+            'mil': self.eval_dict['mil'],
+            'blue': self.eval_dict['blue'],
+            'c108': self.eval_dict['c108'],
+            'red_s': self.red_scores,
+            'mil_s': self.mil_scores,
+            'blue_s': self.blue_scores,
+        }
